@@ -51,7 +51,7 @@ const test = async () => {
         /*const new_frame = (...args) => {
             console.log(args);
         };*/
-        let vn_player = this._native_vn_player = new VN_Player({objid: obj, vsync: false})
+        let vn_player = new VN_Player({objid: obj, vsync: false, frame_buffers_num: 3})
         vn_player.play(url);
 
         /**
@@ -72,7 +72,7 @@ const test = async () => {
                 sleep(15000).then(() => {
                     // finally stop
                     vn_player.teardown();
-                    vn_player = undefined;
+                    vn_player = null;
                 });
             });
         });
